pub unsafe fn enable()Expand description
Enable performance profiling, this function is unsafe for now because you need to call it once before any profiling.
pub unsafe fn enable()Enable performance profiling, this function is unsafe for now because you need to call it once before any profiling.