pub trait LevelGeneratorBuilder {
type Generator: LevelGenerator;
// Required method
fn build(&mut self) -> Self::Generator;
}Expand description
A trait used by LevelGeneratorSource in order to build a specific LevelGenerator in each
worker thread, this allows the generator to be thread unsafe. For this specific use, this
implies that this builder should be send and sync for.
Required Associated Types
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".